@@ -8,13 +8,17 @@ sub new {
   
 }
 
+### diminish
+
 sub lessen_channel {
   my ($self, $less) = @_;
 
   $self->{bitstring} >>= $less;
 }
 
-sub lessen_channel {
+### enlarge
+
+sub greater_channel {
   my ($self, $greater) = @_;
 
   $self->{bitstring} <<= $greater;
